# Unravel The Sound

This application transcribes the voice of a PC speaker.
The AI model is connected to the Internet for downloading, but after that, it runs locally and does not upload data.

# Install

- Install usound with the following command.

```bash
pip install usound
usound -v
```

# Lisence

This project is licensed under the MIT License, see the LICENSE.txt file for details
